<?php

use Polkurier\Util\Arr;

require_once plugin_dir_path(__FILE__) . 'PolkurierOrderStatusUpdater.php';


class Polkurier_WP_List_Table extends WP_List_Table
{

    private static $DEFAULT_PAGE_SIZE = 50;
    private static $MAX_DEFAULT_PAGE_SIZE = 250;

    /**
     * @var \Polkurier\ApiClient|null
     */
    private $api;

    /**
     * @var array|null
     */
    private $couriersByCode;

    public function get_columns()
    {
        $columns = array(
            'mark' => 'Zaznacz',
            'order_number' => 'Numer zamówienia',
            'address' => 'Adres nadawcy',
            'address_to' => 'Adres odbiorcy',
            'date_send' => 'Data nadania',
            'label' => 'Listy przewoz.',
            'status_date' => 'Zmiana statusu',
            'status' => 'Status',
            'delivered_date' => 'Data doręczenia',
            'price' => 'Cena netto/brutto',
            'pobranie' => 'Pobranie',
            'action' => 'Działania',
        );
        return $columns;
    }

    public function get_sortable_columns()
    {
        $sortable_columns = array(
            'order_number' => array('id', false),
            'status_date' => array('status_date', false),
            'status' => array('status', false),
            'delivered_date' => array('delivered_date', false),
            'price_net' => array('price', false),
        );
        return $sortable_columns;
    }

    public function prepare_items($unpaid_only = false)
    {
        $columns = $this->get_columns();
        $hidden = array('_id');
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);

        $orderBy = (!empty($_GET['orderby'])) ? $_GET['orderby'] : 'id';
        $orderDir = (!empty($_GET['order'])) ? $_GET['order'] : 'DESC';

        $currentPage = $this->get_pagenum();
        $pageSize = (int)(!empty($_GET['items_per_page'])) ? $_GET['items_per_page'] : 0;
        if ($pageSize <= 0) {
            $pageSize = self::$DEFAULT_PAGE_SIZE;
        }
        if ($pageSize >= self::$MAX_DEFAULT_PAGE_SIZE) {
            $pageSize = self::$MAX_DEFAULT_PAGE_SIZE;
        }

        $where = [
            'searchQuery' => trim((!empty($_GET['s'])) ? $_GET['s'] : ''),
        ];
        $orders = PolkurierOrder::getAll($where, [$orderBy, $orderDir], $pageSize, ($currentPage - 1) * $pageSize);
        $rowsCount = PolkurierOrder::countAll($where);
        $this->set_pagination_args(array(
            'total_items' => $rowsCount,
            'per_page'    => $pageSize,
        ));

        $statusUpdater = new PolkurierOrderStatusUpdater();
        foreach ($orders as $polkurierOrder) {
            if ($statusUpdater->shouldUpdateOrderStatus($polkurierOrder)) {
                try {
                    $statusUpdater->updateOrderStatus($polkurierOrder);
                } catch (\Polkurier\Exception\ApiException $e) {
                }
            }
            if ($polkurierOrder->status_code !== 'D') {
                $polkurierOrder->delivered_date = null;
                $polkurierOrder->save();
            }
        }
        $this->items = $orders;
    }


    public function column_default($item, $column_name)
    {
        switch ($column_name) {
            case 'date_send':
                return !empty($item['extra']['pickup']['pickupdate'])
                    ? $item['extra']['pickup']['pickupdate']
                    : '';
            case 'price':
                return $item['price_net'] . ' / ' . $item['price_gross'];
            case 'order_number':
                return
                    '<a href="post.php?post=' . $item['wp_order_id'] . '&action=edit">' . $item[$column_name] . '</a>'
                    . '<div style="font-size: 80%;">' . $this->getCourierName($item['carrier']) . '</div>';
            case 'label':
                return $this->formatWaybills($item[$column_name]);
            case 'status_date':
                return ($item[$column_name] == '1970-01-01 01:00') ? '-' : $item[$column_name];
            case 'mark':
                return '<input type="checkbox" name="label[]" value="' . $item['order_number'] . '"/>';
            case 'address':
            case 'address_to':
                return $this->formatAddress($item[$column_name]->address);
            default:
                return $item[$column_name];
        }
    }

    private function getCourierName($courier)
    {
        if ($this->api === null) {
            return $courier;
        }

        if ($this->couriersByCode === null) {
            $this->couriersByCode = [];
            try {
                foreach ($this->api->getAvailableCarriers() as $row) {
                    $this->couriersByCode[$row['servicecode']] = $row['name'];
                }
            } catch (\Polkurier\Exception\ApiException $e) {
            }
        }

        if (isset($this->couriersByCode[$courier])) {
            return $this->couriersByCode[$courier];
        }
        return $courier;
    }

    private function formatWaybills($waybills)
    {
        $rows = [];
        foreach ((array)$waybills as $waybill) {
            $rows[] .= '<li><span>' . $waybill . '</span></li>';
        }
        return '<ul>' . implode('', $rows) . '</ul>';
    }

    private function formatAddress($address)
    {
        if (empty($address)) {
            return '';
        }
        $parts = [];
        $partsExpand = [];

        $country = Arr::get($address, 'country');
        if (empty($country)) {
            $country = 'PL';
        }

        $parts[] = $address["company"];
        $parts[] = $address["person"];
        $parts[] = $address["street"] . " " . $address["housenumber"] . " " . (!empty($address["flatnumber"]) ? (' / ' . $address["flatnumber"]) : '');
        $parts[] = $address["postcode"] . " " . $address["city"] . ' (' . $country . ')';

        $partsExpand[] = $address["phone"];
        $partsExpand[] = $address["email"];
        if (!empty($address['point_name'])) {
            $partsExpand[] = 'Punkt: ' . $address["point_name"];
        }
        return
            implode('<br>', array_filter($parts))
            . (!empty($partsExpand) ? (
                '<div class="pk-expand">'
                    . '<div class="pk-expand-content" style="display: none;">'
                        . implode('<br>', array_filter($partsExpand))
                    . '</div>'
                    . '<a href="#" class="pk-expand-button">[Rozwiń]</a>'
                . '</div>'
                ) : '')
        ;
    }

    public function column_action($item)
    {
        $actions = array(
            'cancel' => sprintf('<a href="?page=%s&action=%s&package=%s&order_id=%s" onclick="return confirm(\'Czy na pewno chcesz anulować zamówienie?\')">Anuluj</a>', $_REQUEST['page'], 'cancel', $item['order_number'], $item['wp_order_id']),
            'download' => sprintf('<a href="?page=%s&action=%s&label=%s&order_id=%s" target="_blank">Pobierz etykietę</a>', $_REQUEST['page'], 'label', $item['order_number'], $item['wp_order_id']),
            'details' => sprintf('<a href="?page=%s&action=%s&label=%s&order_id=%s" target="_blank">Szczegóły</a>', $_REQUEST['page'], 'details', $item['order_number'], $item['wp_order_id']),
        );
        return sprintf('%1$s', $this->row_actions($actions));
    }

    /**
     * @param \Polkurier\ApiClient $api
     * @return $this
     */
    public function set_polkurier_api_client($api)
    {
        if ($api instanceof \Polkurier\ApiClient) {
            $this->api = $api;
        }
        return $this;
    }

}
