<?php


namespace Polkurier\Http;


/**
 * Class Response
 * @package Polkurier\Util
 */
class Response
{

    private $content;
    /**
     * @var int
     */
    private $statusCode;
    /**
     * @var array
     */
    private $headers;

    /**
     * Response constructor.
     * @param mixed $content
     * @param int $code
     * @param array $headers
     */
    public function __construct($content = '', $code = 200, array $headers = [])
    {
        $this->setContent($content);
        $this->statusCode = $code;
        $this->headers = $headers;
    }

    public function setContent($content)
    {
        if (null !== $content && !\is_string($content) && !is_numeric($content) && !\is_callable([$content, '__toString'])) {
            throw new \UnexpectedValueException(sprintf('The Response content must be a string or object implementing __toString(), "%s" given.', \gettype($content)));
        }
        $this->content = (string) $content;
        return $this;
    }

    /**
     * Sends HTTP headers.
     */
    public function sendHeaders()
    {
        if (headers_sent()) {
            return $this;
        }
        foreach ($this->headers as $name => $value) {
            header($name.': '.$value, true, $this->statusCode);
        }
        http_response_code($this->statusCode);
        return $this;
    }

    /**
     * Sends content for the current web response.
     *
     * @return $this
     */
    public function sendContent()
    {
        echo $this->content;
        return $this;
    }

    /**
     * Sends HTTP headers and content.
     *
     * @return $this
     */
    public function send()
    {
        $this->sendHeaders();
        $this->sendContent();
        return $this;
    }

    /**
     * @param $name
     * @param $value
     * @return $this
     */
    public function setHeader($name, $value)
    {
        $this->headers[$name] = $value;
        return $this;
    }

    /**
     * @return mixed
     */
    public function getContent()
    {
        return $this->content;
    }

    /**
     * @return int
     */
    public function getStatusCode()
    {
        return $this->statusCode;
    }

    /**
     * @return array
     */
    public function getHeaders()
    {
        return $this->headers;
    }

}
