<?php

namespace Polkurier\Integrations;

use Polkurier\Http\Request;
use Polkurier\MapsTokenManager;
use Polkurier\Types\CheckoutPointButtonPosition;
use Polkurier\Util\Arr;

class FlexibleShipping extends AbstractIntegration
{

    const ID = 'pk_flexible_shipping';
    const PROVIDER_INPOST = 'INPOST_PACZKOMAT';
    const PROVIDER_PACZKA_W_RUCHU = 'PACZKA_W_RUCHU';
    const PROVIDER_FEDEX = 'FEDEX_DTR';
    const PROVIDER_DPD = 'DPD_POINT';
    const PROVIDER_DHL = 'DHL_POINT';
    const PROVIDER_UPS_ACCESS_POINT = 'UPS_AP_POINT_POINT';
    const PROVIDER_POCZTEX_PUNKT = 'POCZTEX_PUNKT';


    public function __construct()
    {
        add_filter('flexible_shipping_method_settings', [$this, 'flexibleShippingMethodSettings'], 10, 2);
        add_filter('flexible_shipping_process_admin_options', [$this, 'flexibleShippingProcessAdminOptions']);
    }

    /**
     * @param array $settings
     * @param array $shipping_method
     * @return array
     */
    public function flexibleShippingMethodSettings($settings, $shipping_method)
    {
        $settings['pk_flexible_shipping_points_map_title'] = [
            'title' => 'Mapa punktów odbioru przesyłki Polkurier.pl',
            'type' => 'title',
        ];

        $settings['pk_flexible_shipping_points_map_inpost'] = [
            'label' => 'Pokaż punkty InPost',
            'type' => 'checkbox',
            'description' => 'Wyświetla paczkomaty oraz paczko-punkty InPost na mapie wyboru punktu odbioru przesyłki',
        ];

        $settings['pk_flexible_shipping_points_map_orlen'] = [
            'label' => 'Pokaż punkty Orlen Paczka',
            'type' => 'checkbox',
            'description' => 'Wyświetla punkty Orlen Paczka na mapie wyboru punktu odbioru przesyłki',
        ];

        $settings['pk_flexible_shipping_points_map_dpd'] = [
            'label' => 'Pokaż punkty DPD',
            'type' => 'checkbox',
            'description' => 'Wyświetla punkty DPD na mapie wyboru punktu odbioru przesyłki',
        ];

        $settings['pk_flexible_shipping_points_map_fedex'] = [
            'label' => 'Pokaż punkty FedEx',
            'type' => 'checkbox',
            'description' => 'Wyświetla punkty FedEx na mapie wyboru punktu odbioru przesyłki',
        ];

        $settings['pk_flexible_shipping_points_map_dhl'] = [
            'label' => 'Pokaż punkty DHL',
            'type' => 'checkbox',
            'description' => 'Wyświetla punkty DHL na mapie wyboru punktu odbioru przesyłki',
        ];

        $settings['pk_flexible_shipping_points_map_ups'] = [
            'label' => 'Pokaż punkty UPS',
            'type' => 'checkbox',
            'description' => 'Wyświetla punkty UPS na mapie wyboru punktu odbioru przesyłki',
        ];

        $settings['pk_flexible_shipping_points_map_pocztex'] = [
            'label' => 'Pokaż punkty Pocztex',
            'type' => 'checkbox',
            'description' => 'Wyświetla punkty Pocztex na mapie wyboru punktu odbioru przesyłki',
        ];
        return $settings;
    }

    /**
     * @param array $shipping_method
     * @return array
     */
    public function flexibleShippingProcessAdminOptions($shipping_method)
    {
        $request = new Request();
        $shipping_method['pk_flexible_shipping_points_map_inpost'] = (int)$request->getRequest('woocommerce_flexible_shipping_pk_flexible_shipping_points_map_inpost') === 1 ? 'yes' : 'no';
        $shipping_method['pk_flexible_shipping_points_map_orlen'] = (int)$request->getRequest('woocommerce_flexible_shipping_pk_flexible_shipping_points_map_orlen') === 1 ? 'yes' : 'no';
        $shipping_method['pk_flexible_shipping_points_map_dpd'] = (int)$request->getRequest('woocommerce_flexible_shipping_pk_flexible_shipping_points_map_dpd') === 1 ? 'yes' : 'no';
        $shipping_method['pk_flexible_shipping_points_map_fedex'] = (int)$request->getRequest('woocommerce_flexible_shipping_pk_flexible_shipping_points_map_fedex') === 1 ? 'yes' : 'no';
        $shipping_method['pk_flexible_shipping_points_map_dhl'] = (int)$request->getRequest('woocommerce_flexible_shipping_pk_flexible_shipping_points_map_dhl') === 1 ? 'yes' : 'no';
        $shipping_method['pk_flexible_shipping_points_map_ups'] = (int)$request->getRequest('woocommerce_flexible_shipping_pk_flexible_shipping_points_map_ups') === 1 ? 'yes' : 'no';
        $shipping_method['pk_flexible_shipping_points_map_pocztex'] = (int)$request->getRequest('woocommerce_flexible_shipping_pk_flexible_shipping_points_map_pocztex') === 1 ? 'yes' : 'no';
        return $shipping_method;
    }

    /**
     * {@inheritDoc}
     */
    public function onCheckoutProcess()
    {
        $method = \Polkurier::instance()->getCurrentShippingMethod();
        if ($this->shouldShowMapButton($method)) {
            if (empty($_POST['polkurier_point_id']) && WC()->cart->needs_shipping()) {
                wc_add_notice('Wybierz punkt odbioru przesyłki', 'error');
            }
        }
    }

    /**
     * @param \WC_Shipping_Method $method
     * @return bool
     */
    public function shouldShowMapButton($method)
    {
        return
            isset($method->instance_settings) &&
            (
                Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_inpost') === 'yes' ||
                Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_orlen') === 'yes' ||
                Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_dpd') === 'yes' ||
                Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_fedex') === 'yes' ||
                Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_dhl') === 'yes' ||
                Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_ups') === 'yes' ||
                Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_pocztex') === 'yes'
            );
    }

    /**
     * @param \WC_Shipping_Method $method
     * @return void
     */
    public function renderShippingMethod($method)
    {
        $tokenManager = new MapsTokenManager();
        $isCod = WC()->session->get('chosen_payment_method') === 'cod';
        $wasSelected = $this->getPostData('polkurier_method_name') === self::ID;

        $selectedProvider = (string)$this->getPostData('polkurier_provider');
        $selectedPointCod = (bool)$this->getPostData('polkurier_point_cod');
        $selectedPointId = (string)$this->getPostData('polkurier_point_id');
        $selectedPointLabel = (string)$this->getPostData('polkurier_point_label');
        $selectedPointType = (bool)$this->getPostData('polkurier_point_type');

        $providers = [];
        if (isset($method->instance_settings)) {
            if (Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_inpost') === 'yes') {
                $providers[] = self::PROVIDER_INPOST;
            }
            if (Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_orlen') === 'yes') {
                $providers[] = self::PROVIDER_PACZKA_W_RUCHU;
            }
            if (Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_dpd') === 'yes') {
                $providers[] = self::PROVIDER_DPD;
            }
            if (Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_fedex') === 'yes') {
                $providers[] = self::PROVIDER_FEDEX;
            }
            if (Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_dhl') === 'yes') {
                $providers[] = self::PROVIDER_DHL;
            }
            if (Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_ups') === 'yes') {
                $providers[] = self::PROVIDER_UPS_ACCESS_POINT;
            }
            if (Arr::get($method->instance_settings, 'pk_flexible_shipping_points_map_pocztex') === 'yes') {
                $providers[] = self::PROVIDER_POCZTEX_PUNKT;
            }
        }

        if (!$wasSelected || ($isCod && !$selectedPointCod) || !in_array($selectedProvider, $providers, true)) {
            $selectedPointCod = false;
            $selectedPointId = '';
            $selectedPointLabel = '';
        }

        $position = get_option('polkurier_layout_checkout_point_button_position');
        if (!empty(CheckoutPointButtonPosition::MAP_TEMPLATE[$position])) {
            $template = CheckoutPointButtonPosition::MAP_TEMPLATE[$position];
        } else {
            $template = 'checkout/select_shipping_point.php';
        }

        wc_get_template(
            $template,
            [
                'searchAddress' => '',
                'selectedProvider' => $selectedProvider,
                'selectedPointId' => $selectedPointId,
                'selectedPointLabel' => $selectedPointLabel,
                'selectedPointCod' => $selectedPointCod,
                'selectedPointType' => $selectedPointType,
                'apiToken' => (string)$tokenManager->getToken(),
                'providerName' => $providers,
                'isCod' => $isCod,
                'methodId' => self::ID,
                'buttonLabel' => 'Wybierz punkt dostawy',
            ],
            '',
            \Polkurier::instance()->getPluginPath('templates/')
        );
    }

}
