<?php

namespace Polkurier;

/**
 * Class MapsToken
 * @package Polkurier
 */
class MapsToken
{

    /**
     * @var string
     */
    private $token;

    /**
     * @var bool
     */
    private $isValid = false;

    /**
     * @var array
     */
    private $header = array();
    /**
     * @var array
     */
    private $payload = array();

    /**
     * @var string
     */
    private $signature = '';

    /**
     * Polkurier_MapsToken constructor.
     * @param string $token
     */
    public function __construct($token = '')
    {
        $this->parseToken($token);
    }

    /**
     * @return string
     */
    public function __toString()
    {
        return $this->token;
    }

    /**
     * @param string $token
     */
    private function parseToken($token)
    {
        $this->token = (string)$token;
        $this->header = array();
        $this->payload = array();
        $this->signature = '';
        $this->isValid = false;

        if (substr_count($this->token, '.') !== 2) {
            return;
        }

        list($header, $payload, $signature) = explode('.', $this->token);
        if (!empty($header)) {
            $header = json_decode(base64_decode($header), true);
            if (json_last_error() === JSON_ERROR_NONE && is_array($header)) {
                $this->header = $header;
            } else {
                $this->isValid = false;
                return;
            }
        }

        if (!empty($payload)) {
            $payload = json_decode(base64_decode($payload), true);
            if (json_last_error() === JSON_ERROR_NONE && is_array($payload)) {
                $this->payload = $payload;
            } else {
                $this->isValid = false;
                return;
            }
        }

        $this->signature = $signature;
        $this->isValid = true;
    }


    /**
     * @return int
     */
    public function getExp()
    {
        return isset($this->payload['exp']) ? (int)$this->payload['exp'] : 0;
    }

    /**
     * @return bool
     */
    public function isExpired()
    {
        return $this->getExp() < time();
    }

    /**
     * @return bool
     */
    public function isValid()
    {
        return $this->isValid && !$this->isExpired();
    }

    /**
     * @return string
     */
    public function getToken()
    {
        return $this->token;
    }

    /**
     * @return array
     */
    public function getHeader()
    {
        return $this->header;
    }

    /**
     * @return array
     */
    public function getPayload()
    {
        return $this->payload;
    }

    /**
     * @return string
     */
    public function getSignature()
    {
        return $this->signature;
    }

}
